epub property

bool? epub
getter/setter pair

optional

You use the download parameter to restrict the returned results to volumes that have an available download format of epub by setting the to the value epub.

Implementation

bool? epub;