startIndex property
optional
The position in the collection at which to start. The index of the first item is 0
Implementation
int? startIndex;
optional
The position in the collection at which to start. The index of the first item is 0
int? startIndex;