Item class

Constructors

Item({required String? kind, required String? id, required String? etag, required String? selfLink, required VolumeInfo? volumeInfo, required SaleInfo? saleInfo, required AccessInfo? accessInfo, required SearchInfo? searchInfo})
Item.fromJson(Map<String, dynamic> json)
factory

Properties

accessInfo AccessInfo?
final
etag String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
kind String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saleInfo SaleInfo?
final
searchInfo SearchInfo?
final
final
volumeInfo VolumeInfo?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited