VolumeResponseModel class

Constructors

VolumeResponseModel({required String? kind, required int? totalItems, required List<Item> items})
VolumeResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
items List<Item>
final
kind String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalItems int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited